# $Id: Authenticate.pm 35817 2011-10-20 13:08:03Z wsl $
# $URL: https://svn.uvt.nl/its-id/branches/sources/aselect-perl-2/lib/Aselect/UI/SPNEGO/Authenticate.pm $

use strict;
use warnings FATAL => 'all';
use utf8;

package Aselect::UI::SPNEGO::Authenticate;

use Aselect::UI::Login::Document -self;

sub build {
	$self->setDocumentElement($self->construct('spnego'));
}

sub response {
	my $res = super;
	$res->status(401);
	$res->addheader('WWW-Authenticate' => 'Negotiate');
	my $cookie = $self->bakecookie(spnego => 'fail');
	$cookie->expire('1y');
	$res->setcookie($cookie);
	return $res;
}
